UidlRepeat class

Constructors

UidlRepeat({required dynamic dataSource, String asItem = 'item', String? indexKey})
const
UidlRepeat.fromJson(Map<String, dynamic> json)
factory

Properties

asItem String
final
dataSource → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
indexKey String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited