ComponentRegistry class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
registeredTypes
→ Set<
String> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
String type) → WidgetBuilderFn? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
String type, WidgetBuilderFn builder) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
catalogWidgetTypes
→ const List<
String> -
React
defaultWidgetstypes. Native registries must cover every name.