UidlRenderContext class

Constructors

UidlRenderContext({required Map<String, dynamic> state, required Map<String, dynamic> data, required Map<String, dynamic> session, required Map<String, dynamic> route, ComponentRegistry? registry, NavigationHandler? onNavigate, SnackbarHandler? onSnackbar, MutationHandler? onMutate, CommandHandler? onCommand, DownloadHandler? onDownload, void onStateChanged()?})
UidlRenderContext.fromDocument(UidlDocument document, {Map<String, dynamic>? initialData, Map<String, dynamic>? session, Map<String, dynamic>? route, ComponentRegistry? registry, NavigationHandler? onNavigate, SnackbarHandler? onSnackbar, MutationHandler? onMutate, CommandHandler? onCommand, DownloadHandler? onDownload, void onStateChanged()?})
factory

Properties

data Map<String, dynamic>
final
dispatcher ActionDispatcher
latefinal
hashCode int
The hash code for this object.
no setterinherited
registry ComponentRegistry
final
route Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope Map<String, dynamic>
no setter
session Map<String, dynamic>
final
state Map<String, dynamic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited