DocumentVersionException class

Inheritance

Constructors

DocumentVersionException({required String code, required String message, required String rawVersion, int? major, int? minor, dynamic details})

Properties

code String
finalinherited
details → dynamic
finalinherited
hashCode int
The hash code for this object.
no setterinherited
major int?
final
message String
finalinherited
minor int?
final
rawVersion String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited