DocumentVersionReport class

Constructors

DocumentVersionReport({required bool isSupported, int? major, int? minor, required dynamic raw})

Properties

hashCode int
The hash code for this object.
no setterinherited
isSupported bool
final
major int?
final
minor int?
final
raw → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited