UidlDocument class
Constructors
-
UidlDocument({required String version, required String id, required String name, required UidlNode root, Map<
String, dynamic> initialState = const {}, Map<String, dynamic> dataSources = const {}, Map<String, UidlNode> components = const {}, Map<String, dynamic> ? theme, Map<String, dynamic> ? metadata}) -
const
-
UidlDocument.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
components
→ Map<
String, UidlNode> -
final
-
dataSources
→ Map<
String, dynamic> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
initialState
→ Map<
String, dynamic> -
final
-
metadata
→ Map<
String, dynamic> ? -
final
- name → String
-
final
- root → UidlNode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
theme
→ Map<
String, dynamic> ? -
final
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited