UidlNode class
- Annotations
Constructors
-
UidlNode({required String id, required String type, String? componentId, Map<
String, dynamic> props = const {}, Map<String, dynamic> ? style, Map<String, dynamic> ? events, List<UidlNode> children = const [], Map<String, List< ? slots, UidlVisibility? visibility, UidlRepeat? repeat, String? themeRef, String? testId})UidlNode> > -
const
-
UidlNode.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
children
→ List<
UidlNode> -
final
- componentId → String?
-
final
-
events
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
props
→ Map<
String, dynamic> -
final
- repeat → UidlRepeat?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
slots
→ Map<
String, List< ?UidlNode> > -
final
-
style
→ Map<
String, dynamic> ? -
final
- testId → String?
-
final
- themeRef → String?
-
final
- type → String
-
final
- visibility → UidlVisibility?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited