UidlDocumentState class
- Inheritance
-
- Object
- ChangeNotifier
- UidlDocumentState
Constructors
-
UidlDocumentState({required UidlDocument document, Map<
String, dynamic> ? initialData, Map<String, dynamic> ? session, Map<String, dynamic> ? route, ComponentRegistry? registry, SnackbarHandler? onSnackbar, MutationHandler? onMutate, CommandHandler? onCommand, DownloadHandler? onDownload, ApiHandler? onApi, QueryHandler? onQuery})
Properties
-
data
↔ Map<
String, dynamic> -
latefinal
- dispatcher ↔ ActionDispatcher
-
latefinal
- document → UidlDocument
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- onApi ↔ ApiHandler?
-
getter/setter pair
- onCommand ↔ CommandHandler?
-
getter/setter pair
- onDownload ↔ DownloadHandler?
-
getter/setter pair
- onMutate ↔ CommandHandler?
-
getter/setter pair
-
getter/setter pair
- onQuery ↔ QueryHandler?
-
getter/setter pair
- onSnackbar ↔ SnackbarHandler?
-
getter/setter pair
- registry → ComponentRegistry
-
final
-
route
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scope
→ Map<
String, dynamic> -
no setter
-
session
→ Map<
String, dynamic> -
final
-
state
↔ Map<
String, dynamic> -
latefinal
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
executeAction(
dynamic action, [dynamic eventPayload]) → Future< void> -
getState(
String path) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setState(
String path, dynamic value) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateRoute(
String key, dynamic value) → void -
updateSession(
String key, dynamic value) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited